==> fluxbb-1.4.2p4.tgz: fluxbb/lang/English/help.php <==
<?php

// Language definitions used in help.php
$lang_help = array(

'Help'					=>	'Help',
'produces'				=>	'produces',

'BBCode'				=>	'BBCode',
'BBCode info 1'			=>	'BBCode is a collection of formatting tags that are used to change the look of text in this forum. BBCode is based on the same principal as, and is very similar to, HTML. Below is a list of all the available BBCodes and instructions on how to use them.',
'BBCode info 2'			=>	'Administrators have the ability to enable or disable BBCode. You can tell if BBCode is enabled or disabled out in the left margin whenever you post a message or edit your signature.',

'Text style'			=>	'Text style',
'Text style info'		=>	'The following tags change the appearance of text:',
'Bold text'				=>	'Bold text',
'Underlined text'		=>	'Underlined text',
'Italic text'			=>	'Italic text',
'Strike-through text'	=>	'Strike-through text',
'Red text'				=>	'Red text',
'Blue text'				=>	'Blue text',
'Heading text'			=>	'Heading text',
'Deleted text'			=>	'Deleted text',
'Inserted text'			=>	'Inserted text',
'Emphasised text'		=>	'Emphasised text',

'Links and images'		=>	'Links and images',
'Links info'			=>	'You can create links to other documents or to email addresses using the following tags:',
'My email address'		=>	'My email address',
'Images info'			=>	'If you want to display an image you can use the img tag. The text appearing after the "=" sign in the opening tag is used for the alt attribute and should be included whenever possible.',

'Quotes'				=>	'Quotes',
'Quotes info'			=>	'If you want to quote someone, you should use the quote tag.',
'Quotes info 2'			=>	'If you don\'t want to quote anyone in particular, you can use the quote tag without specifying a name.',
'Quote text'			=>	'This is the text i want to quote.',
'produces quote box'	=>	'produces a quote box like this:',
'quote note'			=>	'Note: If a username contains the characters [ or ] you can enclose it in quote marks.',

'Code'					=>	'Code',
'Code info'				=>	'When displaying source code you should make sure that you use the code tag. Text displayed with the code tag will use a monospaced font and will not be affected by other tags.',
'Code text'				=>	'This is some code.',
'produces code box'		=>	'produces a code box like this:',

'Nested tags'			=>	'Nested tags',
'Nested tags info'		=>	'BBCode can be nested to create more advanced formatting. For example:',
'Bold, underlined text'	=>	'Bold, underlined text',

'Lists'					=>	'Lists',
'List info'				=>	'To create a list you can use the list tag. You can create 3 types of lists using the list tag.',
'List text 1'			=>	'Example list item 1.',
'List text 2'			=>	'Example list item 2.',
'List text 3'			=>	'Example list item 3.',
'produces list'			=>	'produces a bulleted list.',
'produces decimal list'	=>	'produces a numbered list.',
'produces alpha list'	=>	'produces an alphabetically labelled list.',

'Smilies'				=>	'Smilies',
'Smilies info'			=>	'If you like (and if it is enabled), the forum can convert a series of smilies to images representations of that smiley. This forum recognizes the following smilies and replaces them with images:'

);

==> fluxbb-1.5.0p0.tgz: fluxbb/lang/English/help.php <==
<?php

// Language definitions used in help.php
$lang_help = array(

'Help'					=>	'Help',
'produces'				=>	'produces',

'BBCode'				=>	'BBCode',
'BBCode info 1'			=>	'BBCode is a collection of formatting tags that are used to change the look of text in this forum. BBCode is based on the same principal as, and is very similar to, HTML. Below is a list of all the available BBCodes and instructions on how to use them.',
'BBCode info 2'			=>	'Administrators have the ability to enable or disable BBCode. You can tell if BBCode is enabled or disabled out in the left margin whenever you post a message or edit your signature.',

'Text style'			=>	'Text style',
'Text style info'		=>	'The following tags change the appearance of text:',
'Bold text'				=>	'Bold text',
'Underlined text'		=>	'Underlined text',
'Italic text'			=>	'Italic text',
'Strike-through text'	=>	'Strike-through text',
'Red text'				=>	'Red text',
'Blue text'				=>	'Blue text',
'Heading text'			=>	'Heading text',
'Deleted text'			=>	'Deleted text',
'Inserted text'			=>	'Inserted text',
'Emphasised text'		=>	'Emphasised text',

'Links and images'		=>	'Links and images',
'Links info'			=>	'You can create links to other documents or to email addresses using the following tags:',
'This help page'		=>	'This help page',
'My email address'		=>	'My email address',
'Images info'			=>	'If you want to display an image you can use the img tag. The text appearing after the "=" sign in the opening tag is used for the alt attribute and should be included whenever possible.',
'FluxBB bbcode test'	=>	'FluxBB bbcode test',

'Test topic'			=>	'Test topic',
'Test post'				=>	'Test post',
'Test forum'			=>	'Test forum',
'Test user'				=>	'Test user',

'Quotes'				=>	'Quotes',
'Quotes info'			=>	'If you want to quote someone, you should use the quote tag.',
'Quotes info 2'			=>	'If you don\'t want to quote anyone in particular, you can use the quote tag without specifying a name.',
'Quote text'			=>	'This is the text i want to quote.',
'produces quote box'	=>	'produces a quote box like this:',
'quote note'			=>	'Note: If a username contains the characters [ or ] you can enclose it in quote marks.',

'Code'					=>	'Code',
'Code info'				=>	'When displaying source code you should make sure that you use the code tag. Text displayed with the code tag will use a monospaced font and will not be affected by other tags.',
'Code text'				=>	'This is some code.',
'produces code box'		=>	'produces a code box like this:',

'Nested tags'			=>	'Nested tags',
'Nested tags info'		=>	'BBCode can be nested to create more advanced formatting. For example:',
'Bold, underlined text'	=>	'Bold, underlined text',

'Lists'					=>	'Lists',
'List info'				=>	'To create a list you can use the list tag. You can create 3 types of lists using the list tag.',
'List text 1'			=>	'Example list item 1.',
'List text 2'			=>	'Example list item 2.',
'List text 3'			=>	'Example list item 3.',
'produces list'			=>	'produces a bulleted list.',
'produces decimal list'	=>	'produces a numbered list.',
'produces alpha list'	=>	'produces an alphabetically labelled list.',

'Smilies'				=>	'Smilies',
'Smilies info'			=>	'If you like (and if it is enabled), the forum can convert a series of smilies to images representations of that smiley. This forum recognizes the following smilies and replaces them with images:'

);
